# PyQtTOTP

## Description

PyQtTOTP is a TOTP QR code generator.

## Installation

```
pip install pyqttotp -U
```

## Usage

```
pyqttotp
```

## Mini Roadmap

- [ ] Add import from few popular TOTP tools (useful during the migration to the other tool).
- [x] Create pip package.

## Screenshot

![Screenshot](https://devcarpet.net/pyqttotp/screenshot00.png)
